CompressTask class

The compress task contains the source file path and the cache file path

Constructors

CompressTask({required String src, required String dest})

Properties

dest String
cache file path
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
src String
source file to compress
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited