CompressTaskFilter class

CompressTaskFilter filter compress tasks by PngHelperConfig

Constructors

CompressTaskFilter(PngHelperConfig config)

Properties

config PngHelperConfig
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tasks List<CompressTask>
final

Methods

filter() List<CompressTask>
Filter all files that meet the conditions according to config.resPaths and config.ignore, and result as CompressTask list.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited