Host class
Constructors
- Host()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- cmdDir → String
-
command directory, same as the root directory of the current script project root
no setter
- optipngPath → String
-
no setter
- pngcrushPath → String
-
no setter
- pngquantPath → String
-
no setter
- pngTempDir → String
-
no setter
- thirdPartyToolsRoot → String
-
no setter
- workDir → String
-
workspace, same as directory where the command is executed
no setter
Static Methods
-
platformFile(
String path) → File